/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_ADSL_FORUM_DHCP_VENDOR_SPECIFIC 255
#define PW_ADSL_FORUM_DEVICE_MANUFACTURER_OUI 255.1
#define PW_ADSL_FORUM_DEVICE_SERIAL_NUMBER 255.2
#define PW_ADSL_FORUM_DEVICE_PRODUCT_CLASS 255.3
#define PW_ADSL_FORUM_GATEWAY_MANUFACTURER_OUI 255.4
#define PW_ADSL_AGENT_CIRCUIT_ID 1
#define PW_ADSL_AGENT_REMOTE_ID 2
#define PW_ACTUAL_DATA_RATE_UPSTREAM 129
#define PW_ACTUAL_DATA_RATE_DOWNSTREAM 130
#define PW_MINIMUM_DATA_RATE_UPSTREAM 131
#define PW_MINIMUM_DATA_RATE_DOWNSTREAM 132
#define PW_ATTAINABLE_DATA_RATE_UPSTREAM 133
#define PW_ATTAINABLE_DATA_RATE_DOWNSTREAM 134
#define PW_MAXIMUM_DATA_RATE_UPSTREAM 135
#define PW_MAXIMUM_DATA_RATE_DOWNSTREAM 136
#define PW_MINIMUM_DATA_RATE_UPSTREAM_LOW_POWER 137
#define PW_MINIMUM_DATA_RATE_DOWNSTREAM_LOW_POWER 138
#define PW_MAXIMUM_INTERLEAVING_DELAY_UPSTREAM 139
#define PW_ACTUAL_INTERLEAVING_DELAY_UPSTREAM 140
#define PW_MAXIMUM_INTERLEAVING_DELAY_DOWNSTREAM 141
#define PW_ACTUAL_INTERLEAVING_DELAY_DOWNSTREAM 142
#define PW_ACCESS_LOOP_ENCAPSULATION 144
#define PW_IWF_SESSION 254
