/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_VQP_PACKET_TYPE 0X2B00
#define PW_VQP_ERROR_CODE 0X2B01
#define PW_VQP_SEQUENCE_NUMBER 0X2B02
#define PW_VQP_CLIENT_IP_ADDRESS 0X2C01
#define PW_VQP_PORT_NAME 0X2C02
#define PW_VQP_VLAN_NAME 0X2C03
#define PW_VQP_DOMAIN_NAME 0X2C04
#define PW_VQP_ETHERNET_FRAME 0X2C05
#define PW_VQP_MAC 0X2C06
#define PW_VQP_UNKNOWN 0X2C07
#define PW_VQP_COOKIE 0X2C08
#define PW_VMPS_PACKET_TYPE 0X2B00
#define PW_VMPS_ERROR_CODE 0X2B01
#define PW_VMPS_SEQUENCE_NUMBER 0X2B02
#define PW_VMPS_CLIENT_IP_ADDRESS 0X2C01
#define PW_VMPS_PORT_NAME 0X2C02
#define PW_VMPS_VLAN_NAME 0X2C03
#define PW_VMPS_DOMAIN_NAME 0X2C04
#define PW_VMPS_ETHERNET_FRAME 0X2C05
#define PW_VMPS_MAC 0X2C06
#define PW_VMPS_UNKNOWN 0X2C07
#define PW_VMPS_COOKIE 0X2C08
