/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_MOBILE_NODE_IDENTIFIER 145
#define PW_SERVICE_SELECTION 146
#define PW_PMIP6_HOME_LMA_IPV6_ADDRESS 147
#define PW_PMIP6_VISITED_LMA_IPV6_ADDRESS 148
#define PW_PMIP6_HOME_LMA_IPV4_ADDRESS 149
#define PW_PMIP6_VISITED_LMA_IPV4_ADDRESS 150
#define PW_PMIP6_HOME_HN_PREFIX 151
#define PW_PMIP6_VISITED_HN_PREFIX 152
#define PW_PMIP6_HOME_INTERFACE_ID 153
#define PW_PMIP6_VISITED_INTERFACE_ID 154
#define PW_PMIP6_HOME_IPV4_HOA 155
#define PW_PMIP6_VISITED_IPV4_HOA 156
#define PW_PMIP6_HOME_DHCP4_SERVER_ADDRESS 157
#define PW_PMIP6_VISITED_DHCP4_SERVER_ADDRESS 158
#define PW_PMIP6_HOME_DHCP6_SERVER_ADDRESS 159
#define PW_PMIP6_VISITED_DHCP6_SERVER_ADDRESS 160
#define PW_PMIP6_HOME_IPV4_GATEWAY 161
#define PW_PMIP6_VISITED_IPV4_GATEWAY 162
