/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_USER_NAME 1
#define PW_USER_PASSWORD 2
#define PW_CHAP_PASSWORD 3
#define PW_NAS_IP_ADDRESS 4
#define PW_NAS_PORT 5
#define PW_SERVICE_TYPE 6
#define PW_FRAMED_PROTOCOL 7
#define PW_FRAMED_IP_ADDRESS 8
#define PW_FRAMED_IP_NETMASK 9
#define PW_FRAMED_ROUTING 10
#define PW_FILTER_ID 11
#define PW_FRAMED_MTU 12
#define PW_FRAMED_COMPRESSION 13
#define PW_LOGIN_IP_HOST 14
#define PW_LOGIN_SERVICE 15
#define PW_LOGIN_TCP_PORT 16
#define PW_REPLY_MESSAGE 18
#define PW_CALLBACK_NUMBER 19
#define PW_CALLBACK_ID 20
#define PW_FRAMED_ROUTE 22
#define PW_FRAMED_IPX_NETWORK 23
#define PW_STATE 24
#define PW_CLASS 25
#define PW_VENDOR_SPECIFIC 26
#define PW_SESSION_TIMEOUT 27
#define PW_IDLE_TIMEOUT 28
#define PW_TERMINATION_ACTION 29
#define PW_CALLED_STATION_ID 30
#define PW_CALLING_STATION_ID 31
#define PW_NAS_IDENTIFIER 32
#define PW_PROXY_STATE 33
#define PW_LOGIN_LAT_SERVICE 34
#define PW_LOGIN_LAT_NODE 35
#define PW_LOGIN_LAT_GROUP 36
#define PW_FRAMED_APPLETALK_LINK 37
#define PW_FRAMED_APPLETALK_NETWORK 38
#define PW_FRAMED_APPLETALK_ZONE 39
#define PW_CHAP_CHALLENGE 60
#define PW_NAS_PORT_TYPE 61
#define PW_PORT_LIMIT 62
#define PW_LOGIN_LAT_PORT 63
