/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_FALL_THROUGH 500
#define PW_RELAX_FILTER 501
#define PW_EXEC_PROGRAM 502
#define PW_EXEC_PROGRAM_WAIT 503
#define PW_AUTH_TYPE 1000
#define PW_MENU 1001
#define PW_TERMINATION_MENU 1002
#define PW_PREFIX 1003
#define PW_SUFFIX 1004
#define PW_GROUP 1005
#define PW_CRYPT_PASSWORD 1006
#define PW_ADD_PREFIX 1008
#define PW_ADD_SUFFIX 1009
#define PW_EXPIRATION 1010
#define PW_AUTZ_TYPE 1011
#define PW_ACCT_TYPE 1012
#define PW_SESSION_TYPE 1013
#define PW_POST_AUTH_TYPE 1014
#define PW_PRE_PROXY_TYPE 1015
#define PW_POST_PROXY_TYPE 1016
#define PW_PRE_ACCT_TYPE 1017
#define PW_EAP_TYPE 1018
#define PW_EAP_TLS_REQUIRE_CLIENT_CERT 1019
#define PW_EAP_ID 1020
#define PW_EAP_CODE 1021
#define PW_EAP_MD5_PASSWORD 1022
#define PW_PEAP_VERSION 1023
#define PW_CLIENT_SHORTNAME 1024
#define PW_LOAD_BALANCE_KEY 1025
#define PW_RAW_ATTRIBUTE 1026
#define PW_TNC_VLAN_ACCESS 1027
#define PW_TNC_VLAN_ISOLATE 1028
#define PW_USER_CATEGORY 1029
#define PW_GROUP_NAME 1030
#define PW_HUNTGROUP_NAME 1031
#define PW_SIMULTANEOUS_USE 1034
#define PW_STRIP_USER_NAME 1035
#define PW_HINT 1040
#define PW_PAM_AUTH 1041
#define PW_LOGIN_TIME 1042
#define PW_STRIPPED_USER_NAME 1043
#define PW_CURRENT_TIME 1044
#define PW_REALM 1045
#define PW_NO_SUCH_ATTRIBUTE 1046
#define PW_PACKET_TYPE 1047
#define PW_PROXY_TO_REALM 1048
#define PW_REPLICATE_TO_REALM 1049
#define PW_ACCT_SESSION_START_TIME 1050
#define PW_ACCT_UNIQUE_SESSION_ID 1051
#define PW_CLIENT_IP_ADDRESS 1052
#define PW_LDAP_USERDN 1053
#define PW_NS_MTA_MD5_PASSWORD 1054
#define PW_SQL_USER_NAME 1055
#define PW_LM_PASSWORD 1057
#define PW_NT_PASSWORD 1058
#define PW_SMB_ACCOUNT_CTRL 1059
#define PW_SMB_ACCOUNT_CTRL_TEXT 1061
#define PW_USER_PROFILE 1062
#define PW_DIGEST_REALM 1063
#define PW_DIGEST_NONCE 1064
#define PW_DIGEST_METHOD 1065
#define PW_DIGEST_URI 1066
#define PW_DIGEST_QOP 1067
#define PW_DIGEST_ALGORITHM 1068
#define PW_DIGEST_BODY_DIGEST 1069
#define PW_DIGEST_CNONCE 1070
#define PW_DIGEST_NONCE_COUNT 1071
#define PW_DIGEST_USER_NAME 1072
#define PW_POOL_NAME 1073
#define PW_MODULE_SUCCESS_MESSAGE 1075
#define PW_MODULE_FAILURE_MESSAGE 1076
#define PW_REWRITE_RULE 1078
#define PW_SQL_QUERY_NUMBER 1079
#define PW_RESPONSE_PACKET_TYPE 1080
#define PW_DIGEST_HA1 1081
#define PW_MS_CHAP_USE_NTLM_AUTH 1082
#define PW_NTLM_USER_NAME 1083
#define PW_MS_CHAP_USER_NAME 1083
#define PW_PACKET_SRC_IP_ADDRESS 1084
#define PW_PACKET_DST_IP_ADDRESS 1085
#define PW_PACKET_SRC_PORT 1086
#define PW_PACKET_DST_PORT 1087
#define PW_PACKET_AUTHENTICATION_VECTOR 1088
#define PW_TIME_OF_DAY 1089
#define PW_REQUEST_PROCESSING_STAGE 1090
#define PW_SHA2_PASSWORD 1092
#define PW_SHA_PASSWORD 1093
#define PW_SSHA_PASSWORD 1094
#define PW_SHA1_PASSWORD 1093
#define PW_SSHA1_PASSWORD 1094
#define PW_MD5_PASSWORD 1095
#define PW_SMD5_PASSWORD 1096
#define PW_PACKET_SRC_IPV6_ADDRESS 1097
#define PW_PACKET_DST_IPV6_ADDRESS 1098
#define PW_VIRTUAL_SERVER 1099
#define PW_CLEARTEXT_PASSWORD 1100
#define PW_PASSWORD_WITH_HEADER 1101
#define PW_INNER_TUNNEL_USER_NAME 1102
#define PW_EAP_IKEV2_IDTYPE 1103
#define PW_EAP_IKEV2_ID 1104
#define PW_EAP_IKEV2_SECRET 1105
#define PW_EAP_IKEV2_AUTHTYPE 1106
#define PW_SEND_DISCONNECT_REQUEST 1107
#define PW_SEND_COA_REQUEST 1107
#define PW_MODULE_RETURN_CODE 1108
#define PW_PACKET_ORIGINAL_TIMESTAMP 1109
#define PW_SQL_TABLE_NAME 1110
#define PW_HOME_SERVER_POOL 1111
#define PW_ATTRIBUTE_MAP 1112
#define PW_COA_PACKET_TYPE 1113
#define PW_COA_PACKET_DST_IP_ADDRESS 1114
#define PW_COA_PACKET_DST_PORT 1115
#define PW_COA_ACCT_SESSION_ID 1116
#define PW_COA_PACKET_DST_IPV6_ADDRESS 1117
#define PW_FREERADIUS_CLIENT_IP_ADDRESS 1120
#define PW_FREERADIUS_CLIENT_IPV6_ADDRESS 1121
#define PW_FREERADIUS_CLIENT_REQUIRE_MA 1122
#define PW_FREERADIUS_CLIENT_SECRET 1123
#define PW_FREERADIUS_CLIENT_SHORTNAME 1124
#define PW_FREERADIUS_CLIENT_NAS_TYPE 1125
#define PW_FREERADIUS_CLIENT_VIRTUAL_SERVER 1126
#define PW_ALLOW_SESSION_RESUMPTION 1127
#define PW_EAP_SESSION_RESUMED 1128
#define PW_EAP_MSK 1129
#define PW_EAP_EMSK 1130
#define PW_RECV_COA_TYPE 1131
#define PW_SEND_COA_TYPE 1132
#define PW_MS_CHAP_PASSWORD 1133
#define PW_PACKET_TRANSMIT_COUNTER 1134
#define PW_CACHED_SESSION_POLICY 1135
#define PW_MS_CHAP_NEW_CLEARTEXT_PASSWORD 1136
#define PW_MS_CHAP_NEW_NT_PASSWORD 1137
#define PW_STRIPPED_USER_DOMAIN 1138
#define PW_CALLED_STATION_SSID 1139
#define PW_CALLED_STATION_MAC 1140
#define PW_PRE_SHARED_KEY 1141
#define PW_PAIRWISE_MASTER_KEY 1142
#define PW_PSK_IDENTITY 1143
#define PW_OTP_CHALLENGE 1145
#define PW_EAP_SESSION_ID 1146
#define PW_CHBIND_RESPONSE_CODE 1147
#define PW_ACCT_INPUT_OCTETS64 1148
#define PW_ACCT_OUTPUT_OCTETS64 1149
#define PW_FREERADIUS_CLIENT_IP_PREFIX 1150
#define PW_FREERADIUS_CLIENT_IPV6_PREFIX 1151
#define PW_FREERADIUS_RESPONSE_DELAY 1152
#define PW_FREERADIUS_CLIENT_SRC_IP_ADDRESS 1153
#define PW_FREERADIUS_CLIENT_SRC_IPV6_ADDRESS 1154
#define PW_FREERADIUS_RESPONSE_DELAY_USEC 1155
#define PW_REST_HTTP_HEADER 1160
#define PW_REST_HTTP_BODY 1161
#define PW_REST_HTTP_STATUS_CODE 1162
#define PW_CACHE_EXPIRES 1170
#define PW_CACHE_CREATED 1171
#define PW_CACHE_TTL 1172
#define PW_CACHE_STATUS_ONLY 1173
#define PW_CACHE_MERGE 1174
#define PW_CACHE_ENTRY_HITS 1175
#define PW_CACHE_READ_ONLY 1176
#define PW_SSHA2_224_PASSWORD 1177
#define PW_SSHA2_256_PASSWORD 1178
#define PW_SSHA2_384_PASSWORD 1179
#define PW_SSHA2_512_PASSWORD 1180
#define PW_PBKDF2_PASSWORD 1181
#define PW_SSHA3_224_PASSWORD 1182
#define PW_SSHA3_256_PASSWORD 1183
#define PW_SSHA3_384_PASSWORD 1184
#define PW_SSHA3_512_PASSWORD 1185
#define PW_PBKDF2_SHA1_PASSWORD 1186
#define PW_PBKDF2_SHA256_PASSWORD 1187
#define PW_PBKDF2_SHA512_PASSWORD 1188
#define PW_PBKDF2_SHA256_LEGACY_PASSWORD 1189
#define PW_MS_CHAP_PEER_CHALLENGE 1192
#define PW_HOME_SERVER_NAME 1193
#define PW_ORIGINATING_REALM_KEY 1194
#define PW_PROXY_TO_ORIGINATING_REALM 1195
#define PW_TOTP_SECRET 1194
#define PW_TOTP_KEY 1195
#define PW_TOTP_PASSWORD 1196
#define PW_PROXY_TUNNELED_REQUEST_AS_EAP 1197
#define PW_TEMP_HOME_SERVER_STRING 1198
#define PW_TOTP_TIME_OFFSET 1199
#define PW_EAP_SIM_SUBTYPE 1200
#define PW_EAP_SIM_RAND1 1201
#define PW_EAP_SIM_RAND2 1202
#define PW_EAP_SIM_RAND3 1203
#define PW_EAP_SIM_SRES1 1204
#define PW_EAP_SIM_SRES2 1205
#define PW_EAP_SIM_SRES3 1206
#define PW_EAP_SIM_STATE 1207
#define PW_EAP_SIM_IMSI 1208
#define PW_EAP_SIM_HMAC 1209
#define PW_EAP_SIM_KEY 1210
#define PW_EAP_SIM_EXTRA 1211
#define PW_EAP_SIM_KC1 1212
#define PW_EAP_SIM_KC2 1213
#define PW_EAP_SIM_KC3 1214
#define PW_EAP_SIM_KI 1215
#define PW_EAP_SIM_ALGO_VERSION 1216
#define PW_OUTER_REALM_NAME 1218
#define PW_INNER_REALM_NAME 1219
#define PW_EAP_PWD_PASSWORD_HASH 1220
#define PW_EAP_PWD_PASSWORD_SALT 1221
#define PW_EAP_PWD_PASSWORD_PREP 1222
#define PW_TEAP_TYPE_MACHINE 1223
#define PW_TEAP_TYPE_USER 1224
#define PW_EAP_TYPE_BASE 1280
#define PW_EAP_TYPE_VALUE 1280
#define PW_EAP_TYPE_NONE 1280
#define PW_EAP_TYPE_IDENTITY 1281
#define PW_EAP_TYPE_NOTIFICATION 1282
#define PW_EAP_TYPE_NAK 1283
#define PW_EAP_TYPE_MD5_CHALLENGE 1284
#define PW_EAP_TYPE_ONE_TIME_PASSWORD 1285
#define PW_EAP_TYPE_GENERIC_TOKEN_CARD 1286
#define PW_EAP_TYPE_RSA_PUBLIC_KEY 1289
#define PW_EAP_TYPE_DSS_UNILATERAL 1290
#define PW_EAP_TYPE_KEA 1291
#define PW_EAP_TYPE_KEA_VALIDATE 1292
#define PW_EAP_TYPE_EAP_TLS 1293
#define PW_EAP_TYPE_DEFENDER_TOKEN 1294
#define PW_EAP_TYPE_RSA_SECURID_EAP 1295
#define PW_EAP_TYPE_ARCOT_SYSTEMS_EAP 1296
#define PW_EAP_TYPE_CISCO_LEAP 1297
#define PW_EAP_TYPE_NOKIA_IP_SMART_CARD 1298
#define PW_EAP_TYPE_SIM 1298
#define PW_EAP_TYPE_SRP_SHA1 1299
#define PW_EAP_TYPE_EAP_TTLS 1301
#define PW_EAP_TYPE_REMOTE_ACCESS_SERVICE 1302
#define PW_EAP_TYPE_AKA 1303
#define PW_EAP_TYPE_EAP_3COM_WIRELESS 1304
#define PW_EAP_TYPE_PEAP 1305
#define PW_EAP_TYPE_MS_EAP_AUTHENTICATION 1306
#define PW_EAP_TYPE_MAKE 1307
#define PW_EAP_TYPE_CRYPTOCARD 1308
#define PW_EAP_TYPE_EAP_MSCHAP_V2 1309
#define PW_EAP_TYPE_DYNAMID 1310
#define PW_EAP_TYPE_ROB_EAP 1311
#define PW_EAP_TYPE_SECURID_EAP 1312
#define PW_EAP_TYPE_MS_AUTHENTICATION_TLV 1313
#define PW_EAP_TYPE_SENTRINET 1314
#define PW_EAP_TYPE_EAP_ACTIONTEC_WIRELESS 1315
#define PW_EAP_TYPE_COGENT_BIOMENTRIC_EAP 1316
#define PW_EAP_TYPE_AIRFORTRESS_EAP 1317
#define PW_EAP_TYPE_EAP_HTTP_DIGEST 1318
#define PW_EAP_TYPE_SECURISUITE_EAP 1319
#define PW_EAP_TYPE_DEVICECONNECT_EAP 1320
#define PW_EAP_TYPE_EAP_SPEKE 1321
#define PW_EAP_TYPE_EAP_MOBAC 1322
#define PW_EAP_TYPE_EAP_FAST 1323
#define PW_EAP_TYPE_ZONELABS 1324
#define PW_EAP_TYPE_EAP_LINK 1325
#define PW_EAP_TYPE_EAP_PAX 1326
#define PW_EAP_TYPE_EAP_PSK 1327
#define PW_EAP_TYPE_EAP_SAKE 1328
#define PW_EAP_TYPE_EAP_IKEV2 1329
#define PW_EAP_TYPE_EAP_AKA2 1330
#define PW_EAP_TYPE_EAP_GPSK 1331
#define PW_EAP_TYPE_EAP_PWD 1332
#define PW_EAP_TYPE_EAP_EVEV1 1333
#define PW_EAP_TYPE_EAP_PT_EAP 1334
#define PW_EAP_TYPE_EAP_TEAP 1335
#define PW_EAP_TYPE_MICROSOFT_MS_CHAPV2 1306
#define PW_EAP_TYPE_CISCO_MS_CHAPV2 1309
#define PW_EAP_TYPE_MS_CHAP_V2 1306
#define PW_EAP_SIM_BASE 1536
#define PW_EAP_SIM_RAND 1537
#define PW_EAP_SIM_PADDING 1542
#define PW_EAP_SIM_NONCE_MT 1543
#define PW_EAP_SIM_PERMANENT_ID_REQ 1546
#define PW_EAP_SIM_MAC 1547
#define PW_EAP_SIM_NOTIFICATION 1548
#define PW_EAP_SIM_ANY_ID_REQ 1549
#define PW_EAP_SIM_IDENTITY 1550
#define PW_EAP_SIM_VERSION_LIST 1551
#define PW_EAP_SIM_SELECTED_VERSION 1552
#define PW_EAP_SIM_FULLAUTH_ID_REQ 1553
#define PW_EAP_SIM_COUNTER 1555
#define PW_EAP_SIM_COUNTER_TOO_SMALL 1556
#define PW_EAP_SIM_NONCE_S 1557
#define PW_EAP_SIM_IV 1665
#define PW_EAP_SIM_ENCR_DATA 1666
#define PW_EAP_SIM_NEXT_PSEUDONUM 1668
#define PW_EAP_SIM_NEXT_REAUTH_ID 1669
#define PW_EAP_SIM_CHECKCODE 1670
#define PW_TMP_STRING_0 1800
#define PW_TMP_STRING_1 1801
#define PW_TMP_STRING_2 1802
#define PW_TMP_STRING_3 1803
#define PW_TMP_STRING_4 1804
#define PW_TMP_STRING_5 1805
#define PW_TMP_STRING_6 1806
#define PW_TMP_STRING_7 1807
#define PW_TMP_STRING_8 1808
#define PW_TMP_STRING_9 1809
#define PW_TMP_INTEGER_0 1810
#define PW_TMP_INTEGER_1 1811
#define PW_TMP_INTEGER_2 1812
#define PW_TMP_INTEGER_3 1813
#define PW_TMP_INTEGER_4 1814
#define PW_TMP_INTEGER_5 1815
#define PW_TMP_INTEGER_6 1816
#define PW_TMP_INTEGER_7 1817
#define PW_TMP_INTEGER_8 1818
#define PW_TMP_INTEGER_9 1819
#define PW_TMP_IP_ADDRESS_0 1820
#define PW_TMP_IP_ADDRESS_1 1821
#define PW_TMP_IP_ADDRESS_2 1822
#define PW_TMP_IP_ADDRESS_3 1823
#define PW_TMP_IP_ADDRESS_4 1824
#define PW_TMP_IP_ADDRESS_5 1825
#define PW_TMP_IP_ADDRESS_6 1826
#define PW_TMP_IP_ADDRESS_7 1827
#define PW_TMP_IP_ADDRESS_8 1828
#define PW_TMP_IP_ADDRESS_9 1829
#define PW_TMP_OCTETS_0 1830
#define PW_TMP_OCTETS_1 1831
#define PW_TMP_OCTETS_2 1832
#define PW_TMP_OCTETS_3 1833
#define PW_TMP_OCTETS_4 1834
#define PW_TMP_OCTETS_5 1835
#define PW_TMP_OCTETS_6 1836
#define PW_TMP_OCTETS_7 1837
#define PW_TMP_OCTETS_8 1838
#define PW_TMP_OCTETS_9 1839
#define PW_TMP_DATE_0 1840
#define PW_TMP_DATE_1 1841
#define PW_TMP_DATE_2 1842
#define PW_TMP_DATE_3 1843
#define PW_TMP_DATE_4 1844
#define PW_TMP_DATE_5 1845
#define PW_TMP_DATE_6 1846
#define PW_TMP_DATE_7 1847
#define PW_TMP_DATE_8 1848
#define PW_TMP_DATE_9 1849
#define PW_TMP_INTEGER64_0 1871
#define PW_TMP_INTEGER64_1 1872
#define PW_TMP_INTEGER64_2 1873
#define PW_TMP_INTEGER64_3 1874
#define PW_TMP_INTEGER64_4 1875
#define PW_TMP_INTEGER64_5 1876
#define PW_TMP_INTEGER64_6 1877
#define PW_TMP_INTEGER64_7 1878
#define PW_TMP_INTEGER64_8 1879
#define PW_TMP_INTEGER64_9 1880
#define PW_TMP_CAST_STRING 1851
#define PW_TMP_CAST_INTEGER 1852
#define PW_TMP_CAST_IPADDR 1853
#define PW_TMP_CAST_DATE 1854
#define PW_TMP_CAST_ABINARY 1855
#define PW_TMP_CAST_OCTETS 1856
#define PW_TMP_CAST_IFID 1857
#define PW_TMP_CAST_IPV6ADDR 1858
#define PW_TMP_CAST_IPV6PREFIX 1859
#define PW_TMP_CAST_BYTE 1860
#define PW_TMP_CAST_SHORT 1861
#define PW_TMP_CAST_ETHERNET 1862
#define PW_TMP_CAST_SIGNED 1863
#define PW_TMP_CAST_INTEGER64 1869
#define PW_TMP_CAST_IPV4PREFIX 1870
#define PW_WIMAX_MN_NAI 1900
#define PW_WIMAX_SIM_KI 1901
#define PW_WIMAX_SIM_OPC 1902
#define PW_WIMAX_SIM_AMF 1903
#define PW_WIMAX_SIM_SQN 1904
#define PW_WIMAX_SIM_RAND 1905
#define PW_TLS_CERT_SERIAL 1910
#define PW_TLS_CERT_EXPIRATION 1911
#define PW_TLS_CERT_ISSUER 1912
#define PW_TLS_CERT_SUBJECT 1913
#define PW_TLS_CERT_COMMON_NAME 1914
#define PW_TLS_CERT_SUBJECT_ALT_NAME_EMAIL 1915
#define PW_TLS_CERT_SUBJECT_ALT_NAME_DNS 1916
#define PW_TLS_CERT_SUBJECT_ALT_NAME_UPN 1917
#define PW_TLS_CERT_VALID_SINCE 1918
#define PW_TLS_SESSION_INFORMATION 1919
#define PW_TLS_CLIENT_CERT_SERIAL 1920
#define PW_TLS_CLIENT_CERT_EXPIRATION 1921
#define PW_TLS_CLIENT_CERT_ISSUER 1922
#define PW_TLS_CLIENT_CERT_SUBJECT 1923
#define PW_TLS_CLIENT_CERT_COMMON_NAME 1924
#define PW_TLS_CLIENT_CERT_FILENAME 1925
#define PW_TLS_CLIENT_CERT_SUBJECT_ALT_NAME_EMAIL 1926
#define PW_TLS_CLIENT_CERT_X509V3_EXTENDED_KEY_USAGE 1927
#define PW_TLS_CLIENT_CERT_X509V3_SUBJECT_KEY_IDENTIFIER 1928
#define PW_TLS_CLIENT_CERT_X509V3_AUTHORITY_KEY_IDENTIFIER 1929
#define PW_TLS_CLIENT_CERT_X509V3_BASIC_CONSTRAINTS 1930
#define PW_TLS_CLIENT_CERT_SUBJECT_ALT_NAME_DNS 1931
#define PW_TLS_CLIENT_CERT_SUBJECT_ALT_NAME_UPN 1932
#define PW_TLS_PSK_IDENTITY 1933
#define PW_TLS_CERT_SUBJECT_ALT_NAME_URI 1934
#define PW_TLS_CLIENT_CERT_SUBJECT_ALT_NAME_URI 1935
#define PW_TLS_CLIENT_CERT_X509V3_EXTENDED_KEY_USAGE_OID 1936
#define PW_TLS_CLIENT_CERT_VALID_SINCE 1937
#define PW_TLS_CACHE_METHOD 1938
#define PW_TLS_CLIENT_CERT_X509V3_CERTIFICATE_POLICIES 1939
#define PW_TLS_SESSION_ID 1940
#define PW_TLS_SESSION_DATA 1942
#define PW_TLS_OCSP_CERT_VALID 1943
#define PW_TLS_CACHE_FILENAME 1946
#define PW_TLS_SESSION_VERSION 1947
#define PW_TLS_SESSION_CIPHER_SUITE 1948
#define PW_TLS_SESSION_CERT_FILE 1949
#define PW_TLS_SESSION_CERT_PRIVATE_KEY_FILE 1950
#define PW_TLS_SERVER_NAME_INDICATION 1951
#define PW_TLS_CERT_CRL_DISTRIBUTION_POINTS 1960
#define PW_TLS_CLIENT_CERT_CRL_DISTRIBUTION_POINTS 1961
#define PW_SOH_MS_MACHINE_OS_VENDOR 2100
#define PW_SOH_MS_MACHINE_OS_VERSION 2101
#define PW_SOH_MS_MACHINE_OS_RELEASE 2102
#define PW_SOH_MS_MACHINE_OS_BUILD 2103
#define PW_SOH_MS_MACHINE_SP_VERSION 2104
#define PW_SOH_MS_MACHINE_SP_RELEASE 2105
#define PW_SOH_MS_MACHINE_PROCESSOR 2106
#define PW_SOH_MS_MACHINE_NAME 2107
#define PW_SOH_MS_CORRELATION_ID 2108
#define PW_SOH_MS_MACHINE_ROLE 2109
#define PW_SOH_SUPPORTED 2119
#define PW_SOH_MS_WINDOWS_HEALTH_STATUS 2120
#define PW_SOH_MS_HEALTH_OTHER 2129
#define PW_RADCLIENT_TEST_NAME 2200
 
#define PW_AUTH_TYPE_LOCAL 1
#define PW_AUTH_TYPE_REJECT 4
#define PW_AUTH_TYPE_ACCEPT 254
#define PW_POST_AUTH_TYPE_LOCAL 1
#define PW_POST_AUTH_TYPE_REJECT 2
#define PW_POST_AUTH_TYPE_CHALLENGE 3
#define PW_POST_AUTH_TYPE_CLIENT_LOST 4
