/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_GSS_ACCEPTOR_SERVICE_NAME 164
#define PW_GSS_ACCEPTOR_HOST_NAME 165
#define PW_GSS_ACCEPTOR_SERVICE_SPECIFICS 166
#define PW_GSS_ACCEPTOR_REALM_NAME 167
